enum cscom {
    callothersubr,
    callsubr,
    closepath,
    csdiv,
    dotsection,
    endchar,
    escape,
    hlineto,
    hmoveto,
    hsbw,
    hstem,
    hstem3,
    hvcurveto,
    pop,
    csreturn,
    rlineto,
    rmoveto,
    rrcurveto,
    sbw,
    seac,
    setcurrentpoint,
    vhcurveto,
    vlineto,
    vmoveto,
    vstem,
    vstem3,
};

typedef enum cscom cscommand;
